# py-thanos

If you are too lazy to run these three commands to delete your virtual environment when you have screwed package installations, then py-thanos will help you erase all the packages in your virtual environent and start afresh.


